// Task Management
const taskInput = document.getElementById('task-input');
const addTaskBtn = document.getElementById('add-task');
const taskList = document.getElementById('task-list');

addTaskBtn.addEventListener('click', () => {
  if (taskInput.value.trim() !== '') {
    const li = document.createElement('li');
    li.innerHTML = `
      <span>${taskInput.value}</span>
      <button class="complete-btn">✔️</button>
    `;
    taskList.appendChild(li);
    taskInput.value = '';
  }
});

taskList.addEventListener('click', (e) => {
  if (e.target.classList.contains('complete-btn')) {
    const taskItem = e.target.parentElement;
    taskItem.classList.add('completed');
    addSticker();
    setTimeout(() => taskItem.remove(), 500);
  }
});

// Timer Functionality
const timerInput = document.getElementById('timer-input');
const startTimerBtn = document.getElementById('start-timer');
const timerDisplay = document.getElementById('timer');
let timerInterval;

startTimerBtn.addEventListener('click', () => {
  const minutes = parseInt(timerInput.value);
  if (minutes > 0) {
    let time = minutes * 60;
    clearInterval(timerInterval);
    timerInterval = setInterval(() => {
      const minutesLeft = Math.floor(time / 60);
      const secondsLeft = time % 60;
      timerDisplay.textContent = `${String(minutesLeft).padStart(2, '0')}:${String(secondsLeft).padStart(2, '0')}`;
      if (time <= 0) {
        clearInterval(timerInterval);
        alert('Time is up!');
      }
      time--;
    }, 1000);
  }
});

// Sticker Board
const stickerContainer = document.getElementById('sticker-container');
const stickers = ['🌟', '🎉', '🏆', '💯', '👏', '🎓', '📚', '✨'];

function addSticker() {
  const sticker = document.createElement('div');
  sticker.className = 'sticker';
  sticker.textContent = stickers[Math.floor(Math.random() * stickers.length)];
  sticker.style.left = `${Math.random() * 80}%`;
  sticker.style.top = `${Math.random() * 80}%`;
  stickerContainer.appendChild(sticker);
}

// Progress Chart
const ctx = document.getElementById('progress-chart').getContext('2d');
const progressChart = new Chart(ctx, {
  type: 'line',
  data: {
    labels: ['Week 1', 'Week 2', 'Week 3', 'Week 4'],
    datasets: [{
      label: 'Tasks Completed',
      data: [3, 7, 12, 18],
      borderColor: var(--primary-color),
      fill: false
    }]
  },
  options: {
    responsive: true,
    maintainAspectRatio: false,
    scales: {
      y: {
        beginAtZero: true
      }
    }
  }
});

// Voice Recording
const recordBtn = document.getElementById('record-btn');
let mediaRecorder;
let audioChunks = [];

recordBtn.addEventListener('click', async () => {
  if (!mediaRecorder) {
    try {
      const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
      mediaRecorder = new MediaRecorder(stream);
      mediaRecorder.ondataavailable = event => {
        audioChunks.push(event.data);
      };
      mediaRecorder.onstop = () => {
        const audioBlob = new Blob(audioChunks, { type: 'audio/wav' });
        const audioUrl = URL.createObjectURL(audioBlob);
        const audio = new Audio(audioUrl);
        audio.play();
        audioChunks = [];
      };
      mediaRecorder.start();
      recordBtn.textContent = '⏹️ Stop Recording';
    } catch (error) {
      alert('Error accessing microphone');
    }
  } else {
    mediaRecorder.stop();
    mediaRecorder = null;
    recordBtn.textContent = '🎤 Record Note';
  }
});